<?php

namespace Controllers;

use Exception;
use Exception\CustomException;
use Traits\TResponse;
use Util\InstanceProvider;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;

class Login
{
    use TResponse;

    /** @var \Services\Login $loginService */
    protected $loginService;

    /**
     * @param \Services\Login $loginService
     */
    public function __construct(\Services\Login $loginService) {
        $this->loginService = $loginService;
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws Exception
     */
    public function login(Request $request, Response $response) {
        try {
            $user          = $request->getParameter('EMAIL');
            $password      = $request->getParameter('PASSWORD');
            $productId     = $request->getParameter('PRODUCT_ID');
            $requesterUrl  = $request->getParameter('REQUESTER_URL');
            $attempts      = $request->getParameter('ATTEMPTS');
            $fullOperator  = $request->getParameter('SHOW_FULL_OPERATOR');
            $hash          = $request->getParameter('HASH');
            $sessionChange = $request->getParameter('SESSION_CHANGE');
            $keepConnected = $request->getParameter('KEEP_CONNECTED');
            $userData      = $this->loginService->login($user, $password, $productId, $requesterUrl, $attempts, $fullOperator, $hash, $sessionChange, $keepConnected);
            $this->sendResponse($userData, 200);
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request\DataSet $request
     * @param Response $response
     * @throws Exception
     */
    public function setLogAccess(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows()[0];
            $userId = $row['USER_ID'];
            $this->loginService->setLogAccess($userId);
        }catch (CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     */
    public function validateUser(Request $request, Response $response) {
        try {
            $params = $request->getParameters();
            $password           = $params['PASSWORD'];
            $isSupportOperator  = $params['IS_SUPPORT_OPERATOR'];
            $userValidation= $this->loginService->validateUser($password, $isSupportOperator);
            $this->sendResponse($userValidation, 200);;
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws Exception
     */
    public function getProductLanguages(Request $request, Response $response) {
        try {
            $productId = $request->getParameter('productId');
            $languages  = $this->loginService->getProductLanguages($productId);
            $this->sendResponse($languages, 200);
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request\Filter $request
     * @param Response $response
     */
    public function testLicenseConnection(Request\Filter $request, Response $response) {
        try {
            $result = $this->loginService->testLicenseConnection();
            $response->addDataSet(new DataSet('testLicenseConnection', $result));
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }
}
