<?php

namespace Controllers;

use Exception;
use Exception\CustomException;
use Traits\TResponse;
use Util\Utilities;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;

class Password
{
    use TResponse;
    /** @var \Services\Password $passwordService */
    protected $passwordService;

    /**
     * @param \Services\Password $passwordService
     */
    public function __construct(\Services\Password $passwordService) {
        $this->passwordService = $passwordService;
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws Exception
     */
    public function requestNewPassword(Request $request, Response $response) {
        try {
            $params = $request->getParameters();
            $email      = $params['email'] ?? null;
            $style      = $params['style'] ?? null;
            $this->passwordService->requestNewPassword($email, $style);
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws \Zeedhi\Framework\DTO\Exception
     */
    public function updatePassword(Request $request, Response $response) {
        try {
            $actualPassword = $request->getParameter('actualPassword');
            $newPassword    = $request->getParameter('newPassword');
            $newPassConfirm = $request->getParameter('newPasswordConfirmation');
            $email          = $request->getParameter('email');
            $this->passwordService->updatePassword($actualPassword, $newPassword, $newPassConfirm, $email);
        } catch(CustomException $e) {
            $this->sendResponse(Utilities::getErrorObjectFromException($e), 500);
        }
    }
}
