<?php

namespace Repositories;

use Util\InstanceProvider;

class OAccTekMgr {
    /**
     * @param $nrOrg
     * @param $defaultOrgId
     * @return array
     */
    public function getOAccTekMgrByNrOrg($nrOrg, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $query = "SELECT RECURRENCE_DAYS, NRORG, OACCTEK_PHP7 AS OACCTEK, TO_CHAR(DTULTATU, 'DD/MM/YYYY') AS DTULTATU
                    FROM OACCTEKMGR
                   WHERE NRORG = :NRORG";

        $params = array(
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }

    public function getDbHostInfo() {
        $query = 'SELECT DBID || \'_\' || USER AS DBINFO
                    FROM V$DATABASE';

        $entityManager = InstanceProvider::getEntityManager();
        $result = $entityManager->getConnection()->fetchAll($query);

        return !empty($result) ? $result[0]['DBINFO'] : '';
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @param $recurrenceDays
     * @param $oAccTek
     * @param $defaultOrgId
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function insertOAccTekMgr($nrOrg, $cdOperator , $recurrenceDays, $oAccTek, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $query = "INSERT INTO OACCTEKMGR
                              (NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, RECURRENCE_DAYS, OACCTEK_PHP7, OACCTEK)
                       VALUES (:NRORG, SYSDATE, SYSDATE, :NRORG, :CDOPERADOR, :RECURRENCE_DAYS, :OACCTEK, :OACCTEK)";

        $params = array(
            'NRORG'           => $nrOrg,
            'CDOPERADOR'      => $cdOperator,
            'RECURRENCE_DAYS' => $recurrenceDays,
            'OACCTEK'         => $oAccTek
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @param $recurrenceDays
     * @param $oAccTek
     * @param $defaultOrgId
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function updateOAccTekMgr($nrOrg, $cdOperator , $recurrenceDays, $oAccTek, $defaultOrgId = null) {
        $defaultOrgId = $defaultOrgId ?: $nrOrg;
        $query = "UPDATE OACCTEKMGR
                     SET OACCTEK_PHP7 = :OACCTEK,
                         RECURRENCE_DAYS = :RECURRENCE_DAYS,
                         NRORGULTATU = :NRORG,
                         DTULTATU = SYSDATE,
                         CDOPERULTATU = :CDOPERADOR
                   WHERE NRORG = :NRORG";

        $params = array(
            'NRORG'           => $nrOrg,
            'CDOPERADOR'      => $cdOperator,
            'RECURRENCE_DAYS' => $recurrenceDays,
            'OACCTEK'         => $oAccTek
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($defaultOrgId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }
}